@@ -24,6 +24,7 @@
 #include <signal.h>
 #include <glib/gi18n.h>
 #include "gtk-compat.h"
+#include "pan/gui/load-icon.h"
 #include <gmime/gmime.h>
 #include <gio/gio.h>
 
@@ -50,12 +51,10 @@ extern "C" {
 #endif
 
 #ifdef HAVE_GKR
-#if GTK_CHECK_VERSION(3,0,0)
   #define GCR_API_SUBJECT_TO_CHANGE
   #include <libsecret/secret.h>
   #include <gcr/gcr.h>
   #undef GCR_API_SUBJECT_TO_CHANGE
-#endif /* GTK_CHECK_VERSION(3,0,0) */
 #endif
 
 #include <config.h>
@@ -83,6 +82,8 @@ extern "C" {
 //#define DEBUG_LOCALE 1
 //#define DEBUG_PARALLEL 1
 
+#include <pan/general/null.h>
+
 using namespace pan;
 
 namespace
@@ -92,7 +93,7 @@ namespace
 
 namespace
 {
-  GMainLoop * nongui_gmainloop (0);
+  GMainLoop * nongui_gmainloop (nullptr);
 
   void mainloop ()
   {
@@ -196,13 +197,13 @@ namespace
   const guint8 * pixbuf_txt;
   GdkPixbuf * pixbuf;
   } status_icons[NUM_STATUS_ICONS] = {
-    { icon_status_online,          0 },
-    { icon_status_offline,         0 },
-    { icon_status_active,          0 },
-    { icon_status_queue_empty,     0 },
-    { icon_status_error,           0 },
-    { icon_status_idle,            0 },
-    { icon_status_new_articles,    0 }
+    { icon_status_online,          nullptr },
+    { icon_status_offline,         nullptr },
+    { icon_status_active,          nullptr },
+    { icon_status_queue_empty,     nullptr },
+    { icon_status_error,           nullptr },
+    { icon_status_idle,            nullptr },
+    { icon_status_new_articles,    nullptr }
   };
 
 
@@ -272,8 +273,8 @@ namespace
     bool n() { return notif_shown; }
 
     StatusIconListener(GtkStatusIcon * i, GtkWidget* r, Prefs& p, Queue& q, Data& d, bool v) :
-      icon(i), root(r), prefs(p), queue(q), data(d), minimized(v),
-      tasks_active(0), tasks_total(0), notif_shown(false)
+      queue(q), data(d), tasks_active(0), tasks_total(0),
+      minimized(v), notif_shown(false), prefs(p), icon(i), root(r)
     {
       prefs.add_listener(this);
       queue.add_listener(this);
@@ -303,15 +304,15 @@ namespace
     }
 
     /* prefs::listener */
-    virtual void on_prefs_flag_changed (const StringView &key, bool value)
+    void on_prefs_flag_changed (const StringView &key, bool value) override
     {
        if(key == "status-icon")
          gtk_status_icon_set_visible(icon, value);
     }
 
-    virtual void on_prefs_int_changed (const StringView& key, int color) {}
-    virtual void on_prefs_string_changed (const StringView& key, const StringView& value) {}
-    virtual void on_prefs_color_changed (const StringView& key, const GdkColor& color) {}
+    void on_prefs_int_changed (const StringView& key, int color) override {}
+    void on_prefs_string_changed (const StringView& key, const StringView& value) override {}
+    void on_prefs_color_changed (const StringView& key, const GdkColor& color) override {}
 
     void update_status_tooltip()
     {
@@ -381,20 +382,20 @@ namespace
     }
 
     /* queue::listener */
-    virtual void on_queue_task_active_changed (Queue&, Task&, bool active) {}
-    virtual void on_queue_tasks_added (Queue&, int index UNUSED, int count)
+    void on_queue_task_active_changed (Queue&, Task&, bool active) override {}
+    void on_queue_tasks_added (Queue&, int index UNUSED, int count) override
     {
       tasks_total += count;
       update_status_tooltip();
       update_status_icon(ICON_STATUS_ACTIVE);
     }
-    virtual void on_queue_task_removed (Queue&, Task&, int pos UNUSED)
+    void on_queue_task_removed (Queue&, Task&, int pos UNUSED) override
     {
       update_status_icon(ICON_STATUS_ACTIVE);
     }
-    virtual void on_queue_task_moved (Queue&, Task&, int new_pos UNUSED, int old_pos UNUSED) {}
-    virtual void on_queue_connection_count_changed (Queue&, int count) {}
-    virtual void on_queue_size_changed (Queue&, int active, int total)
+    void on_queue_task_moved (Queue&, Task&, int new_pos UNUSED, int old_pos UNUSED) override {}
+    void on_queue_connection_count_changed (Queue&, int count) override {}
+    void on_queue_size_changed (Queue&, int active, int total) override
     {
       tasks_total = total;
       tasks_active = active;
@@ -403,7 +404,7 @@ namespace
       update_status_tooltip();
     }
 
-    virtual void on_queue_online_changed (Queue&, bool online)
+    void on_queue_online_changed (Queue&, bool online) override
     {
       is_online = online;
       if (tasks_total)
@@ -414,7 +415,7 @@ namespace
       update_status_tooltip();
     }
 
-    virtual void on_queue_error (Queue&, const StringView& message)
+    void on_queue_error (Queue&, const StringView& message) override
     {
       update_status_icon(ICON_STATUS_ERROR);
       if (n()) return;
@@ -422,13 +423,11 @@ namespace
       notify_of(ICON_STATUS_ERROR, message.str, _("An error has occurred!"));
     }
 
-    virtual void on_queue_size_changed (Queue&, unsigned long, unsigned long) {}
-
     /* data::listener */
-    virtual void on_group_entered (const Quark& group, unsigned long unread, unsigned long total)
+    void on_group_entered (const Quark& group, Article_Count unread, Article_Count total) override
     {
 
-      if (unread)
+      if (static_cast<uint64_t>(unread) != 0)
       {
         update_status_icon(ICON_STATUS_NEW_ARTICLES);
         if (n()) return;
@@ -480,7 +479,7 @@ namespace
     gtk_menu_popup(menu, NULL, NULL, NULL, NULL, button, activation_time);
   }
 
-  static QueueAndGui* queue_and_gui(0);
+  static QueueAndGui* queue_and_gui(nullptr);
 
   void run_pan_with_status_icon (GtkWindow * window, GdkPixbuf * pixbuf, Queue& queue, Prefs & prefs, Data& data, GUI* _gui)
   {
@@ -488,7 +487,7 @@ namespace
     GUI& gui (*_gui);
 
     for (guint i=0; i<NUM_STATUS_ICONS; ++i)
-      status_icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, status_icons[i].pixbuf_txt, FALSE, 0);
+      status_icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, status_icons[i].pixbuf_txt, FALSE, nullptr);
 
     GtkStatusIcon * icon = gtk_status_icon_new_from_pixbuf (status_icons[ICON_STATUS_IDLE].pixbuf);
     GtkWidget * menu = gtk_menu_new ();
@@ -577,17 +576,17 @@ namespace
     ~PanKiller() { q.remove_listener(this); }
 
     /** Method from Queue::Listener interface: quits program on zero sized Q*/
-    void on_queue_size_changed (Queue&, int active, int total)
+    void on_queue_size_changed (Queue&, int active, int total) override
       {  if (!active && !total) mainloop_quit();  }
 
     // all below methods from Queue::Listener interface are noops
-    void on_queue_task_active_changed (Queue&, Task&, bool) {}
-    void on_queue_tasks_added (Queue&, int , int ) {}
-    void on_queue_task_removed (Queue&, Task&, int) {}
-    void on_queue_task_moved (Queue&, Task&, int, int) {}
-    void on_queue_connection_count_changed (Queue&, int) {}
-    void on_queue_online_changed (Queue&, bool) {}
-    void on_queue_error (Queue&, const StringView&) {}
+    void on_queue_task_active_changed (Queue&, Task&, bool) override {}
+    void on_queue_tasks_added (Queue&, int , int ) override {}
+    void on_queue_task_removed (Queue&, Task&, int) override {}
+    void on_queue_task_moved (Queue&, Task&, int, int) override {}
+    void on_queue_connection_count_changed (Queue&, int) override {}
+    void on_queue_online_changed (Queue&, bool) override {}
+    void on_queue_error (Queue&, const StringView&) override {}
 
   private:
     Queue & q;
@@ -617,8 +616,8 @@ namespace
     cerr.ios::rdbuf( t2 );
     err.ios::rdbuf( tmp );
 
-    freopen( "CONOUT$", "w", stdout );
-    freopen( "CONOUT$", "w", stderr );
+    (void)freopen( "CONOUT$", "w", stdout );
+    (void)freopen( "CONOUT$", "w", stderr );
   }
 #else
   void console()
@@ -834,7 +833,7 @@ _("General Options\n"
 
 namespace
 {
-  GUI * gui_ptr (0);
+  GUI * gui_ptr (nullptr);
 }
 
 namespace
@@ -848,7 +847,6 @@ namespace
     std::string fg_col, bg_col;
 
     // init colors of PanColors
-#if GTK_CHECK_VERSION(3,0,0)
     GdkRGBA fg_color, bg_color;
     GtkStyleContext* ctx = gtk_widget_get_style_context(r);
     if(!ctx || !gtk_style_context_lookup_color(ctx, "color", &fg_color))
@@ -867,14 +865,6 @@ namespace
       def_bg.green = bg_color.red;
       def_bg.blue = bg_color.blue;
     }
-#else
-    GtkStyle *style = gtk_rc_get_style(r);
-    if(!style || !gtk_style_lookup_color(style, "text_color", &def_fg))
-      gdk_color_parse("black", &def_fg);
-    if(!style || !gtk_style_lookup_color(style, "bg_color", &def_bg))
-      gdk_color_parse("white", &def_bg);
-
-#endif
 
     //todo move to pancolors
     fg_col = GroupPrefs::color_to_string(def_fg);
@@ -907,11 +897,7 @@ main (int argc, char *argv[])
 #if !GLIB_CHECK_VERSION(2,32,0)
   g_thread_init (0);
 #endif
-#ifdef HAVE_GMIME_30
   g_mime_init ();
-#else
-  g_mime_init (GMIME_ENABLE_RFC2047_WORKAROUNDS);
-#endif  
 
   bool gui(true), nzb(false), verbosed(false);
   std::string url;
@@ -1082,18 +1068,18 @@ main (int argc, char *argv[])
       }
 
       // if in non-gui mode, contains a PanKiller ptr to quit pan on queue empty
-      std::auto_ptr<PanKiller> killer;
+      std::unique_ptr<PanKiller> killer;
 
       // don't open the full-blown Pan, just act as a nzb client,
       // with a gui or without.
       if (gui) {
         TaskPane * pane = new TaskPane (queue, prefs);
         GtkWidget * w (pane->root());
-        GdkPixbuf * pixbuf = gdk_pixbuf_new_from_inline (-1, icon_pan, FALSE, 0);
+        GdkPixbuf * pixbuf = gdk_pixbuf_new_from_inline (-1, icon_pan, FALSE, nullptr);
         gtk_window_set_default_icon (pixbuf);
         gtk_widget_show_all (w);
-        g_signal_connect (w, "destroy", G_CALLBACK(destroy_cb), 0);
-        g_signal_connect (G_OBJECT(w), "delete-event", G_CALLBACK(delete_event_cb), 0);
+        g_signal_connect (w, "destroy", G_CALLBACK(destroy_cb), nullptr);
+        g_signal_connect (G_OBJECT(w), "delete-event", G_CALLBACK(delete_event_cb), nullptr);
       } else {
         nongui_gmainloop = g_main_loop_new (NULL, false);
         // create a PanKiller object -- which quits pan when the queue is done
@@ -1104,7 +1090,7 @@ main (int argc, char *argv[])
     }
     else
     {
-      GdkPixbuf * pixbuf = gdk_pixbuf_new_from_inline (-1, icon_pan, FALSE, 0);
+      GdkPixbuf* pixbuf = load_icon("icon_pan.png");
       GtkWidget * window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
       if (prefs.get_flag ("main-window-is-maximized", false))
         gtk_window_maximize (GTK_WINDOW (window));
@@ -1161,11 +1147,7 @@ main (int argc, char *argv[])
       Data::Server* s(data.find_server(*it));
       if (s && s->gkr_pw)
       {
-#if GTK_CHECK_VERSION(3,0,0)
         gcr_secure_memory_free(s->gkr_pw);
-#else
-        gnome_keyring_memory_free(s->gkr_pw);
-#endif /* GTK_CHECK_VERSION(3,0,0) */
       }
     }
   }
